package es.verdnatura.presentation.view.feature.paletizador.model

class ItemScanVO (
    var expeditionFk:String = "",
    var palletFk:String = "",
    var isError:Boolean = false,
    var errorMessage:String = ""
)

class ItemScanList(
    var list:List<ItemScanVO> = listOf()
)

class ItemExpeditionScanVO(
    var id:String = "",
    var expeditionFk:String = "",
    var Ruta:String = "",
    var Ticket:String = "",
    var Caja:String = "",
    var isError:Boolean = false,
    var errorMessage:String = ""
)

class ItemExpeditionScanList(
    var list:List<ItemExpeditionScanVO> = listOf()
)

